%define upstream_name Perl-Tidy-Sweetened
%define upstream_version 1.20

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Tweaks to Perl::Tidy to support some syntactic sugar
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Perl/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Module::Build::Tiny) >= 0.34.0
BuildRequires: perl(Perl::Tidy) >= 20230309.0.0
BuildRequires: perl(Test::Differences)
BuildRequires: perl(Test::More) >= 0.870.0
BuildRequires: perl(Test::Most)
BuildArch:  noarch

%description
There are a number of modules on CPAN that allow users to write their
classes with a more "modern" syntax. These tools eliminate the need to
shift off $self, can support type checking and offer other improvements.
Unfortunately, they can break the support tools that the Perl community
has come to rely on. This module attempts to work around those issues.

The module uses Perl::Tidy's "prefilter" and "postfilter" hooks to
support "method" and "func" keywords, including the (possibly
multi-line) parameter lists. This is quite an ugly hack, but it is the
recommended method of supporting these new keywords (see the 2010-12-17
entry in the Perl::Tidy CHANGES
<https://metacpan.org/source/SHANCOCK/Perl-Tidy-20120714/CHANGES> file).
The resulting formatted code will leave the parameter lists untouched.

"Perl::Tidy::Sweetened" attempts to support the syntax outlined in the
following modules, but most of the new syntax styles should work:
*   p5-mop
*   Method::Signatures::Simple
*   MooseX::Method::Signatures
*   MooseX::Declare
*   Moops
*   MooseX::Declare
*   perl 5.20 signatures

%prep
%autosetup -n %{upstream_name}-%{upstream_version} -p 1

%build
perl Build.PL --installdirs=vendor
./Build

%install
./Build install --destdir=%{buildroot}
%_fixperms %{buildroot}

%check
./Build test

%files
%license LICENSE
%doc Changes LICENSE META.json META.yml MYMETA.yml README TODO
%{_bindir}/*
%{_mandir}/man1/*
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Tue Aug 29 2023 tv <tv> 1.200.0-1.mga10
+ Revision: 1981007
- update to 1.20

* Mon Mar 21 2022 umeabot <umeabot> 1.180.0-2.mga9
+ Revision: 1814098
- Mageia 9 Mass Rebuild

* Thu Feb 25 2021 tv <tv> 1.180.0-1.mga9
+ Revision: 1691411
- update to 1.18

* Sun Dec 13 2020 guillomovitch <guillomovitch> 1.160.0-2.mga8
+ Revision: 1656452
- fix tests
+ tv <tv>
- use %%license

* Fri Apr 10 2020 tv <tv> 1.160.0-1.mga8
+ Revision: 1566084
- update to 1.16

* Fri Feb 14 2020 umeabot <umeabot> 1.150.0-2.mga8
+ Revision: 1519759
- Mageia 8 Mass Rebuild

* Sat Oct 20 2018 tv <tv> 1.150.0-1.mga7
+ Revision: 1322693
- update to 1.15

* Thu Sep 20 2018 umeabot <umeabot> 1.120.0-2.mga7
+ Revision: 1285717
- Mageia 7 Mass Rebuild

* Wed Jul 19 2017 sander85 <sander85> 1.120.0-1.mga7
+ Revision: 1125059
- update to 1.12

* Sun May 08 2016 shlomif <shlomif> 1.110.0-1.mga6
+ Revision: 1010757
- update to 1.11

* Fri Apr 15 2016 shlomif <shlomif> 1.100.0-1.mga6
+ Revision: 1002287
- New version 1.10

* Sun Mar 13 2016 shlomif <shlomif> 1.90.0-1.mga6
+ Revision: 989841
- update to 1.09

* Wed Feb 10 2016 shlomif <shlomif> 1.70.0-1.mga6
+ Revision: 953364
- update to 1.07

* Sun Aug 23 2015 sander85 <sander85> 1.50.0-1.mga6
+ Revision: 868639
- update to 1.05

* Thu Aug 13 2015 sander85 <sander85> 1.40.0-1.mga6
+ Revision: 864513
- imported package perl-Perl-Tidy-Sweetened

